"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const redux_1 = require("redux");
const redux_2 = require("redux");
const redux_di_middleware_1 = require("redux-di-middleware");
const RootReducer_1 = require("./RootReducer");
/**
 * gets a configuration object for the Store instance
 * @param {DocumentViewerSettings} settings The Settings object for the document viewer instance
 */
exports.getStoreConfig = (settings) => {
    const di = new redux_di_middleware_1.ReduxDiMiddleware(settings.injector);
    di.setInjectable(settings);
    return {
        rootReducer: RootReducer_1.rootReducer,
        preloadedState: { sensenetDocumentViewer: { documentState: { isLoading: true } } },
        enhancer: composeEnhancers(redux_2.applyMiddleware(di.getMiddleware())),
    };
};
const composeEnhancers = window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || redux_1.compose;
/**
 * returns a Store object for a Document Viewer instance
 * @param {DocumentViewerSettings} settings The Settings object for the document viewer instance
 */
exports.configureStore = settings => {
    const config = exports.getStoreConfig(settings);
    return redux_2.createStore(config.rootReducer, config.preloadedState, config.enhancer);
};
tslib_1.__exportStar(require("./Comments"), exports);
tslib_1.__exportStar(require("./Document"), exports);
tslib_1.__exportStar(require("./PreviewImages"), exports);
tslib_1.__exportStar(require("./RootReducer"), exports);
tslib_1.__exportStar(require("./Viewer"), exports);
//# sourceMappingURL=index.js.map